@@ -3,12 +3,12 @@
 """
 
 from datetime import datetime
+from gplist.plist import PlistInfo, PY2
 import binascii
 
 from cryptography import x509
 from cryptography.hazmat import backends
 from cryptography.hazmat.primitives.hashes import SHA1
-from gplist.plist import PlistInfo, PY2
 
 
 class Cert(object):
@@ -16,6 +16,23 @@ class Cert(object):
     def __init__(self, cert_obj):
         self._cert = cert_obj
         self._sha1 = None
+        self._uid = None
+        self._common_name = None
+        self._unit_name = None
+        self._org_name = None
+        self._country_name = None
+        for item in self._cert.subject:
+            key, value = item.rfc4514_string().split("=")
+            if key == "UID":
+                self._uid = value
+            elif key == "CN":
+                self._common_name = value
+            elif key == "OU":
+                self._unit_name = value
+            elif key == "O":
+                self._org_name = value
+            elif key == "C":
+                self._country_name = value
 
     @property
     def cert(self):
@@ -31,6 +48,26 @@ class Cert(object):
             self._sha1 = data.upper()
         return self._sha1
 
+    @property
+    def serial(self):
+        return hex(self._cert.serial_number).upper()
+
+    @property
+    def common_name(self):
+        return self._common_name
+
+    @property
+    def organization_unit_name(self):
+        return self._unit_name
+
+    @property
+    def organization_name(self):
+        return self._org_name
+
+    @property
+    def country_name(self):
+        return self._country_name
+
     @property
     def invalid_before(self):
         return self._cert.not_valid_before
