@@ -21,7 +21,7 @@ else:
     string_type = str
 
 
-STRUCT_SIZE_MAP = {1: "B", 2: "H", 4: "I", 8: "Q"}
+STRUCT_SIZE_MAP = {1: "B", 2: "H", 4: "I", 8: "q", 16: "Q"}
 
 
 def unzip(file_path, dir_path, members=None):
@@ -148,10 +148,10 @@ class PlistInfo(OrderedDict):
 
     def _parse_binary(self):
         tailer = self._binary_data[-32:]
-        unit_size, self.ref_size, obj_count, top, table_offset = struct.unpack(
+        unit_size, self.ref_size, self.obj_count, top, table_offset = struct.unpack(
             ">6xBBQQQ", tailer)
         self.obj_offsets = self._read_ints(
-            obj_count, unit_size, table_offset)
+            self.obj_count, unit_size, table_offset)
         self._read_object(top)
 
     def _read_object(self, obj_index):
@@ -174,7 +174,10 @@ class PlistInfo(OrderedDict):
             result = ""
         elif token_h == 0x10:  # int
             length = 1 << token_l
-            end = start + length
+            if length == 16:  # unsigned long long
+                end = start + 8
+            else:
+                end = start + length
             struct_type = STRUCT_SIZE_MAP[length]
             obj_buf = self._binary_data[start:end]
             result = struct.unpack(">" + struct_type, obj_buf)[0]
@@ -277,8 +280,6 @@ class PlistInfo(OrderedDict):
             token = 0x8
         elif value is True:
             token = 0x9
-        elif value == "":
-            token = 0xf
         elif isinstance(value, int):
             token_h = 0x10
             value_buf, token_l, _ = self._pack_int(value)
@@ -431,11 +432,14 @@ class PlistInfo(OrderedDict):
         return obj_count
 
     def to_binary(self):
+        import biplist
+        return biplist.writePlistToString(self)
+
         self.obj_index = 0
         self.obj_offsets = {}
         self._values = {}
-        obj_count = self._get_obj_count()
-        self.ref_size = self._pack_int(obj_count)[2]
+        self.obj_count = self._get_obj_count()
+        self.ref_size = self._pack_int(self.obj_count)[2]
         _, buf, offset = self._write_object(self, 0, 8)
         if (len(buf) + 8) != offset:
             raise RuntimeError(
@@ -443,7 +447,7 @@ class PlistInfo(OrderedDict):
         for obj_offset in self.obj_offsets.values():
             buf += struct.pack(">H", obj_offset)
 
-        buf += struct.pack(">6xBBQQQ", 2, self.ref_size, obj_count,
+        buf += struct.pack(">6xBBQQQ", 2, self.ref_size, self.obj_count,
                            0, offset)
         return b"bplist00" + buf
 
